# -*- coding: utf8 -*-
#  Toggle Text Wrapping Plugin
#
#  Copyright (C) 2008 Javier Paniagua <jpaniagualaconich@gmail.com>
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

# CHANGELOG
# =========
#
# * 2008-08-27:
#   Initial Release

from gettext import gettext as _

import gconf
import gtk
import gedit

# Menu item example, insert a new item in the Tools menu
ui_str = """<ui>
  <menubar name="MenuBar">
    <menu name="ViewMenu" action="View">
      <menuitem name="ToggleTextWrap" action="ToggleTextWrap"/>
    </menu>
  </menubar>
</ui>
"""
class ToggleTextWrapWindowHelper:
    def __init__(self, plugin, window):
        self._window = window
        self._plugin = plugin
        # Insert menu items
        self._insert_menu()
        self.gconf_client = gconf.client_get_default ();
        self.gconf_client.add_dir ("/apps/gedit-2/preferences/editor/wrap_mode",
                  gconf.CLIENT_PRELOAD_NONE)

    def deactivate(self):
        # Remove any installed menu items
        self._remove_menu()

        self.gconf_client.unref ()
        self._window = None
        self._plugin = None
        self._action_group = None

    def _insert_menu(self):
        # Get the GtkUIManager
        manager = self._window.get_ui_manager()

        # Create a new action group
        self._action_group = gtk.ActionGroup("ToggleTextWrapPluginActions")
        self._action_group.add_actions([("ToggleTextWrap", None, _("Toggle text wrap"),
                                         None, _("Toggles text wrap on/off"),
                                         self.on_toggle_text_wrap_activate)])

        # Insert the action group
        manager.insert_action_group(self._action_group, -1)

        # Merge the UI
        self._ui_id = manager.add_ui_from_string(ui_str)

    def _remove_menu(self):
        # Get the GtkUIManager
        manager = self._window.get_ui_manager()

        # Remove the ui
        manager.remove_ui(self._ui_id)

        # Remove the action group
        manager.remove_action_group(self._action_group)

        # Make sure the manager updates
        manager.ensure_update()

    def update_ui(self):
        self._action_group.set_sensitive(self._window.get_active_document() != None)

    # Menu activate handlers
    def on_toggle_text_wrap_activate(self, action):
        if self.gconf_client.get_string("/apps/gedit-2/preferences/editor/wrap_mode/wrap_mode") == "GTK_WRAP_NONE":
            self.gconf_client.set_string("/apps/gedit-2/preferences/editor/wrap_mode/wrap_mode", "GTK_WRAP_WORD")
        else:
            self.gconf_client.set_string("/apps/gedit-2/preferences/editor/wrap_mode/wrap_mode", "GTK_WRAP_NONE")

class ToggleTextWrapPlugin(gedit.Plugin):
    def __init__(self):
        gedit.Plugin.__init__(self)
        self._instances = {}

    def activate(self, window):
        self._instances[window] = ToggleTextWrapWindowHelper(self, window)

    def deactivate(self, window):
        self._instances[window].deactivate()
        del self._instances[window]

    def update_ui(self, window):
        self._instances[window].update_ui()


